@@ -28,7 +28,7 @@
 #'    
 #'  #Get Data
 #'  data("SolitaryTinamou")
-#'  proj <- CRS("+proj=longlat +ellps=WGS84")
+#'  proj <- "+proj=longlat +ellps=WGS84"
 #'  data <- SolitaryTinamou$datasets
 #'  mesh <- SolitaryTinamou$mesh
 #'  mesh$crs <- proj
@@ -159,8 +159,8 @@ datasetOut <- function(model, dataset,
     
     reduced_terms <- unique(unlist(lapply(model$bru_info$lhoods[index], function(x) {
       
-      if (!is.null(x$include_components)) x$include_components
-      else labels(terms(x))
+      if (!identical(unlist(x$used), character(0))) unlist(x$used)
+      else labels(terms(x$formula))
       
     })))
     
@@ -215,9 +215,9 @@ datasetOut <- function(model, dataset,
         #else covs <- model$spatCovs$name
         train <- predict(model_reduced, data = model$bru_info$lhoods[[data]]$data, formula = eval(parse(text = paste0('~(',paste(gsub('\\(.*$', '', labels(terms(reduced_components))), collapse = ' + '),')'))))  
        
-        reduced_lik[[data]]$data@data['offset'] <- train$predictions$mean
+        reduced_lik[[data]]$data[,'offset'] <- train$predictions$mean
         #reduced_lik[[data]]$formula <- update(reduced_lik[[data]]$formula, ~ . + offset)
-        reduced_lik[[data]]$include_components <- c(reduced_lik[[data]]$include_components, 'offset')
+        reduced_lik[[data]]$used$effect <- c(reduced_lik[[data]]$used$effect, 'offset')
         
       }
      
